/*
 * Copyright (c) 2002, 2004 Gargoyle Software Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. The end-user documentation included with the redistribution, if any, must
 *    include the following acknowledgment:
 *
 *       "This product includes software developed by Gargoyle Software Inc.
 *        (http://www.GargoyleSoftware.com/)."
 *
 *    Alternately, this acknowledgment may appear in the software itself, if
 *    and wherever such third-party acknowledgments normally appear.
 * 4. The name "Gargoyle Software" must not be used to endorse or promote
 *    products derived from this software without prior written permission.
 *    For written permission, please contact info@GargoyleSoftware.com.
 * 5. Products derived from this software may not be called "GSBase", nor may
 *    "GSBase" appear in their name, without prior written permission of
 *    Gargoyle Software Inc.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GARGOYLE
 * SOFTWARE INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.gargoylesoftware.base.gui;

import com.gargoylesoftware.base.util.DetailedNullPointerException;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import java.io.PrintWriter;
import java.io.StringWriter;

/**
 * A panel that can display an exception stack trace.
 *
 * @version $Revision: 1.5 $
 * @author <a href="mailto:mbowler@GargoyleSoftware.com">Mike Bowler</a>
 */
public class ThrowablePanel extends JScrollPane {
	private static final long serialVersionUID = 1;
    private Throwable throwable_ = null;
    private final JTextArea textArea_;

    /**
     * Create a new panel.
     */
    public ThrowablePanel() {
        super( new JTextArea() );
        textArea_ = (JTextArea)getViewport().getView();
    }

    /**
     * Create a new panel.
     * @param t The exception to display.
     */
    public ThrowablePanel( final Throwable t ) {
        this();
        setException(t);
    }

    /**
     * Set the exception that is being displayed.
     * @param t The new exception.
     */
    public void setException( final Throwable t ) {
        assertNotNull("t", t);
        throwable_ = t;
        textArea_.setText( makeString(t) );
    }

    /**
     * Return the exception that is being displayed.
     * @return The exception.
     */
    public Throwable getException() {
        return throwable_;
    }

    /**
     * Make a string from the exception.
     * @param t The throwable object
     * @return A string containing the stack trace
     */
    private static String makeString( final Throwable t ) {
        final StringWriter stringWriter = new StringWriter();
        final PrintWriter printWriter = new PrintWriter(stringWriter);
        t.printStackTrace(printWriter);

        return stringWriter.toString();
    }


    /**
     * Verify that the specified value is not null.  If it is then throw an exception
     *
     * @param fieldName The name of the field to check
     * @param fieldValue The value of the field to check
     * @exception DetailedNullPointerException If fieldValue is null
     */
    protected final void assertNotNull( final String fieldName, final Object fieldValue )
        throws DetailedNullPointerException {

        if( fieldValue == null ) {
            throw new DetailedNullPointerException(fieldName);
        }
    }
}

