/*
 * Copyright (c) 2002, 2004 Gargoyle Software Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. The end-user documentation included with the redistribution, if any, must
 *    include the following acknowledgment:
 *
 *       "This product includes software developed by Gargoyle Software Inc.
 *        (http://www.GargoyleSoftware.com/)."
 *
 *    Alternately, this acknowledgment may appear in the software itself, if
 *    and wherever such third-party acknowledgments normally appear.
 * 4. The name "Gargoyle Software" must not be used to endorse or promote
 *    products derived from this software without prior written permission.
 *    For written permission, please contact info@GargoyleSoftware.com.
 * 5. Products derived from this software may not be called "GSBase", nor may
 *    "GSBase" appear in their name, without prior written permission of
 *    Gargoyle Software Inc.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GARGOYLE
 * SOFTWARE INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.gargoylesoftware.base.trace;

import java.util.Collection;
import java.util.Iterator;
import java.util.Map;

/**
 * A collection of utility methods dealing with tracing.
 *
 * @version $Revision: 1.3 $
 * @author <a href="mailto:mbowler@GargoyleSoftware.com">Mike Bowler</a>
 */
public class TraceUtil {

   private static final String LINE_SEPARATOR
       = System.getProperty("line.separator");

   private TraceUtil(){
   }

   /**
    * Dump a collection to the specified TraceChannel.
    * @param channel The channel to write the information to.
    * @param collection The data to write.
    */
   public static void trace( final TraceChannel channel,
                 final Collection collection ) {

      final StringBuffer buffer = new StringBuffer();
      buffer.append("collection=[");
      buffer.append(collection.getClass().getName());
      buffer.append("]");

      final Iterator iterator = collection.iterator();
      while( iterator.hasNext() ) {
     buffer.append( LINE_SEPARATOR );
         buffer.append( "   " );
     buffer.append( iterator.next() );
      }

      Trace.println( channel, buffer.toString() );
   }

   /**
    * Dump a map to the specified TraceChannel.
    * @param channel The channel to write the information to.
    * @param collection The data to write.
    */
   public static void trace( final TraceChannel channel,
                 final Map collection ) {
       Map.Entry entry;

       final StringBuffer buffer = new StringBuffer();
       buffer.append("map=[");
       buffer.append(collection.getClass().getName());
       buffer.append("]");

       final Iterator iterator = collection.entrySet().iterator();
       while( iterator.hasNext() ) {
       entry = (Map.Entry)iterator.next();
       buffer.append( LINE_SEPARATOR );
       buffer.append( "   " );
       buffer.append( entry.getKey() );
       buffer.append( "=" );
       buffer.append( entry.getValue() );
       }

      Trace.println( channel, buffer.toString() );
   }

   /**
    * Dump an object array to the specified TraceChannel.
    * @param channel The channel to write the information to.
    * @param array The data to write.
    */
   public static void trace( final TraceChannel channel,
                 final Object[] array ) {
       final StringBuffer buffer = new StringBuffer();
       buffer.append("Array size=[");
       buffer.append(array.length);
       buffer.append("]");
       int i;
       for( i=0; i<array.length; i++ ) {
       buffer.append(LINE_SEPARATOR);
       buffer.append("   array[");
       buffer.append(i);
       buffer.append("]=");
       buffer.append(array[i]);
       }

      Trace.println( channel, buffer.toString() );
   }
}

