/*
 * Copyright (c) 2002, 2004 Gargoyle Software Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. The end-user documentation included with the redistribution, if any, must
 *    include the following acknowledgment:
 *
 *       "This product includes software developed by Gargoyle Software Inc.
 *        (http://www.GargoyleSoftware.com/)."
 *
 *    Alternately, this acknowledgment may appear in the software itself, if
 *    and wherever such third-party acknowledgments normally appear.
 * 4. The name "Gargoyle Software" must not be used to endorse or promote
 *    products derived from this software without prior written permission.
 *    For written permission, please contact info@GargoyleSoftware.com.
 * 5. Products derived from this software may not be called "GSBase", nor may
 *    "GSBase" appear in their name, without prior written permission of
 *    Gargoyle Software Inc.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GARGOYLE
 * SOFTWARE INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.gargoylesoftware.base.util;


/**
 * A more detailed version of IllegalArgumentException that contains
 * information about what argument was not legal.
 *
 * @version  $Revision: 1.4 $
 * @author  <a href="mailto:mbowler@GargoyleSoftware.com">Mike Bowler</a>
 */
public class DetailedIllegalArgumentException extends IllegalArgumentException {
    private static final long serialVersionUID = -6090279070118149533L;
	private final String argumentName_;
    private final Object argumentValue_;


    /**
     * Create an instance
     *
     * @param argumentName The name of the argument that was illegal
     * @param argumentValue The illegal value
     * @param message The message to use in the exception
     */
    public DetailedIllegalArgumentException(
            final String argumentName, final Object argumentValue, final String message ) {

        super("argumentName=["+argumentName+"] argumentValue=["+argumentValue+"]"
            + (message==null?"":" message=["+message+"]"));

        argumentName_ = argumentName;
        argumentValue_ = argumentValue;
    }


    /**
     * Create an instance
     *
     * @param argumentName The name of the argument that was illegal
     * @param argumentValue The illegal value
     */
    public DetailedIllegalArgumentException(
            final String argumentName, final Object argumentValue ) {

        this( argumentName, argumentValue, null );
    }


    /**
     * Create an instance
     *
     * @param argumentName The name of the argument that was illegal
     * @param argumentValue The illegal value
     * @param message A message
     */
    public DetailedIllegalArgumentException(
            final String argumentName, final int argumentValue, final String message ) {

        this(argumentName, new Integer(argumentValue), message);
    }


    /**
     * Create an instance
     *
     * @param argumentName The name of the argument that was illegal
     * @param argumentValue The illegal value
     */
    public DetailedIllegalArgumentException(
            final String argumentName, final int argumentValue ) {

        this(argumentName, new Integer(argumentValue));
    }


    /**
     * Return the name of the argument that was illegal
     * @return the name of the argument
     */
    public String getArgumentName() {
        return argumentName_;
    }


    /**
     * Return the value of the argument
     * @return The value of the argument
     */
    public Object getArgumentValue() {
        return argumentValue_;
    }
}

