/*
 * Copyright (c) 2002, 2004 Gargoyle Software Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. The end-user documentation included with the redistribution, if any, must
 *    include the following acknowledgment:
 *
 *       "This product includes software developed by Gargoyle Software Inc.
 *        (http://www.GargoyleSoftware.com/)."
 *
 *    Alternately, this acknowledgment may appear in the software itself, if
 *    and wherever such third-party acknowledgments normally appear.
 * 4. The name "Gargoyle Software" must not be used to endorse or promote
 *    products derived from this software without prior written permission.
 *    For written permission, please contact info@GargoyleSoftware.com.
 * 5. Products derived from this software may not be called "GSBase", nor may
 *    "GSBase" appear in their name, without prior written permission of
 *    Gargoyle Software Inc.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GARGOYLE
 * SOFTWARE INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.gargoylesoftware.base.gui;

import com.gargoylesoftware.base.testing.SampleBean;
import java.beans.IntrospectionException;
import java.util.Arrays;
import java.util.List;
import junit.framework.TestCase;

/**
 * Tests for ReflectedTableModel
 *
 * @version  $Revision: 1.5 $
 * @author <a href="mailto:mbowler@GargoyleSoftware.com">Mike Bowler</a>
 */
public class ReflectedTableModelTest extends TestCase {

    /**
     * Create a new test.
     * @param name The name of the test.
     */
    public ReflectedTableModelTest( final String name ) {
        super(name);
    }

    /**
     * Test the constructor that takes a class.
     * @throws IntrospectionException If an error occurs while getting the property information
     * for the class.
     */
    public void testClassConstructor() throws IntrospectionException {
        final ReflectedTableModel model = new ReflectedTableModel( SampleBean.class );
        final List columns = model.getColumns();

        final String sampleBeanProperties[] = {
            "age",
            "class",
            "name"
        };

        ReflectedTableModel.ColumnInfo columnInfo;
        final int maxCount = columns.size();
        final String foundProperties[] = new String[maxCount];
        assertEquals( "Number of columns", sampleBeanProperties.length, columns.size() );
        int i;
        for( i=0; i<maxCount; i++ ) {
            columnInfo = (ReflectedTableModel.ColumnInfo)columns.get(i);
            foundProperties[i] = columnInfo.getPropertyName();
        }

        Arrays.sort(foundProperties);
        if( Arrays.equals( foundProperties, sampleBeanProperties ) == false ) {
            fail("Properties were different from expected");
        }
    }

    /**
     * Test getValueAt()
     * @throws IntrospectionException If an error occurs while getting the property information
     * for the class.
     */
    public void testGetValueAt() throws IntrospectionException {
        final ReflectedTableModel model = new ReflectedTableModel( SampleBean.class );
        final List rows = model.getRows();

        final Object data[][] = {
            { "Mickey", new Integer( 5)},
            { "Minnie", new Integer(10)},
            { "Goofy",  new Integer(15)},
            { "Pluto",  new Integer(20)},
        };

        int i;
        for( i=0; i<data.length; i++ ) {
            rows.add( new SampleBean( (String)data[i][0], ((Integer)data[i][1]).intValue() ) );
        }

        assertEquals("Number of rows", data.length, model.getRowCount() );

        int nameColumnIndex = -1;
        int ageColumnIndex = -1;

        String columnName;

        final int columnCount = model.getColumnCount();
        for( i=0; i<columnCount; i++ ) {
            columnName = model.getColumnName(i);
            if( columnName.equals("name") ) {
                nameColumnIndex = i;
            }
            else if( columnName.equals("age") ) {
                ageColumnIndex = i;
            }
        }

        assertTrue( "nameColumnIndex not found", nameColumnIndex != -1 );
        assertTrue( "ageColumnIndex not found", ageColumnIndex != -1 );

        for( i=0; i<data.length; i++ ) {
            assertEquals( "Name["+i+"]",
                          data[i][0],
                          model.getValueAt(i, nameColumnIndex) );

            assertEquals( "Age["+i+"]",
                          data[i][1],
                          model.getValueAt(i, ageColumnIndex) );
        }
    }
}





