/*
 * Copyright (c) 2002, 2004 Gargoyle Software Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. The end-user documentation included with the redistribution, if any, must
 *    include the following acknowledgment:
 *
 *       "This product includes software developed by Gargoyle Software Inc.
 *        (http://www.GargoyleSoftware.com/)."
 *
 *    Alternately, this acknowledgment may appear in the software itself, if
 *    and wherever such third-party acknowledgments normally appear.
 * 4. The name "Gargoyle Software" must not be used to endorse or promote
 *    products derived from this software without prior written permission.
 *    For written permission, please contact info@GargoyleSoftware.com.
 * 5. Products derived from this software may not be called "GSBase", nor may
 *    "GSBase" appear in their name, without prior written permission of
 *    Gargoyle Software Inc.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GARGOYLE
 * SOFTWARE INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.gargoylesoftware.base.util;

import java.sql.Connection;
import junit.framework.TestCase;

/**
 * Tests for ProxyUtil
 *
 * @version $Revision: 1.4 $
 * @author <a href="mailto:mbowler@GargoyleSoftware.com">Mike Bowler</a>
 */
public final class ProxyUtilTest extends TestCase {

    /**
     * Create a test
     * @param name The name of the test
     */
    public ProxyUtilTest( final String name ) {
        super(name);
    }


    /**
     * Test the constructor that just takes a class by passing in null.
     */
    public void testCreateProxyWithoutArgs_Null() {
        try {
            ProxyUtil.createProxy(null);
            fail("Expected exception for null class");
        }
        catch( final NullPointerException e ) {
            // Expected path
        }
    }


    /**
     * Test the constructor that takes just a class.
     */
    public void testCreateProxyWithoutArgs() {
        final Object object = ProxyUtil.createProxy(Connection.class);

        assertNotNull(object);
        assertTrue("instanceof", object instanceof Connection );
    }


    /**
     * Test the two arg constructor with a null class
     */
    public void testCreateProxy_Null() {
        try {
            ProxyUtil.createProxy(null, new Object[0][]);
            fail("Expected exception for null class");
        }
        catch( final NullPointerException e ) {
            // Expected path
        }
    }


    /**
     * Test the two arg constructor with arguments
     * @throws Exception If an error occurs
     */
    public void testCreateProxyWithArgs() throws Exception {
        final Object args[][] = {
            {"getAutoCommit", Boolean.TRUE},
            {"getCatalog", "foobar"}
        };
        final Object object = ProxyUtil.createProxy(Connection.class, args);

        assertNotNull(object);
        assertTrue("instanceof", object instanceof Connection );

        final Connection connection = (Connection)object;
        assertTrue( connection.getAutoCommit() );
        assertEquals("foobar", connection.getCatalog());
    }
}
